@@ -1,6 +1,3 @@
-import json
-
-
 def serialize_id(pk):
     if isinstance(pk, (int, str)):
         return pk
@@ -104,24 +101,6 @@ def get_tree_queryset(model, node_id=None, max_level=None, include_root=True):
     return qs.order_by("tree_id", "lft")
 
 
-def get_javascript_value(value):
-    """
-    Get javascript value for python value.
-
-    >>> get_javascript_value(True)
-    true
-    >>> get_javascript_value(10)
-    10
-    """
-    if isinstance(value, bool):
-        if value:
-            return "true"
-        else:
-            return "false"
-    else:
-        return json.dumps(value)
-
-
 def get_model_name(model):
     """
     Get the name of a Django model
